| PPC | R Documentation |
FitTT objectsCreate the PPC object to be pass in plot function for plotting the
Posterior Predictive Check.#'
ppc(fit, ...)
## S3 method for class 'ContinuousFitTT'
ppc(fit, ...)
## S3 method for class 'CountFitTT'
ppc(fit, ...)
## S3 method for class 'BinaryFitTT'
ppc(fit, ...)
fit |
An object of class |
... |
Further arguments to be passed to generic methods |
An object of class 'PPC'
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.