PlotData: Plotting method for 'BinaryData', 'CountData' or...

PlotDataR Documentation

Plotting method for BinaryData, CountData or ContinuousData.

Description

This is the generic plot S3 method for the BinaryData, CountData and ContinuousData classes.

  • BinaryData: It plots the sum of non-failure (survivor, mobile) individuals as a function of time.

  • CountData: It plots the cumulated number of offspring as a function of time.

  • Continuous: It plots the continuous data as a function of time by concentration panels.

Usage

## S3 method for class 'BinaryData'
plot(
  x,
  xlab = "Time",
  ylab = "Sum of Non-Failure",
  main = NULL,
  concentration = NULL,
  pool.replicate = FALSE,
  addlegend = FALSE,
  ...
)

## S3 method for class 'ContinuousData'
plot(
  x,
  xlab = "Time",
  ylab = "Measure",
  main = NULL,
  concentration = NULL,
  addlegend = FALSE,
  ...
)

## S3 method for class 'CountData'
plot(
  x,
  xlab = "Time",
  ylab = "Cumulated Response",
  main = NULL,
  concentration = NULL,
  pool.replicate = FALSE,
  addlegend = FALSE,
  ...
)

Arguments

x

an object of class BinaryData, CountData or ContinuousData

xlab

a label for the X-axis, by default Time

ylab

a label for the Y-axis, by default Sum of Non-Failure for BinaryData, Cumulated Response for CountData, and Measure for ContinuousData.

main

title for the plot

concentration

a numeric value corresponding to some concentration(s) in data. If concentration = NULL, draws a plot for each concentration

pool.replicate

if TRUE, the datapoints of each replicate are summed for a same concentration

addlegend

if TRUE, adds a default legend to the plot

...

Further arguments to be passed to generic methods

Value

a plot of class ggplot


morseDR documentation built on June 8, 2025, 10:20 a.m.