PlotDoseResponse: Plot dose-response from 'DoseResponse' objects

PlotDoseResponseR Documentation

Plot dose-response from DoseResponse objects

Description

This is the generic plot S3 method for the DoseResponse class. It plots the survival probability as a function of concentration at a given target time.

  • For BinaryData object: The function plots the observed values of the survival probability at a given time point as a function of concentration. The 95% binomial confidence interval is added to each survival probability. It is calculated using function binom.test from package stats. Replicates are systematically pooled in this plot.

  • For CountData object: The function plots the observed values of the Number of at a given time point as a function of concentration. The 95% binomial confidence interval is added to each survival probability. It is calculated using function poisson.test. Replicates are systematically pooled in this plot.

  • For ContinuousData object: the function plots observed values of the response at a given time point as a function of concentration. The 95% binomial confidence interval is added to each set of data at each concentration. It is calculated using function t.test from package stats.

Usage

## S3 method for class 'DoseResponse'
plot(
  x,
  xlab = "Dose",
  ylab = NULL,
  main = NULL,
  log.scale = FALSE,
  addlegend = TRUE,
  dodge.width = 0,
  ...
)

## S3 method for class 'BinaryDoseResponse'
plot(
  x,
  xlab = "Concentration",
  ylab = NULL,
  main = NULL,
  log.scale = FALSE,
  addlegend = TRUE,
  dodge.width = 0,
  ...
)

## S3 method for class 'CountDoseResponse'
plot(
  x,
  xlab = "Concentration",
  ylab = NULL,
  main = NULL,
  log.scale = FALSE,
  addlegend = TRUE,
  dodge.width = 0,
  ...
)

## S3 method for class 'ContinuousDoseResponse'
plot(
  x,
  xlab = "Concentration",
  ylab = NULL,
  main = NULL,
  log.scale = FALSE,
  addlegend = TRUE,
  dodge.width = 0,
  ...
)

Arguments

x

an object of class BinaryData, CountData or ContinuousData

xlab

a label for the X-axis, by default Dose

ylab

a label for the Y-axis, by default Response

main

main title for the plot

log.scale

if TRUE, displays X-axis in log-scale

addlegend

if TRUE, adds a default legend to the plot

dodge.width

dodging width. Dodging preserves the vertical position of an geom while adjusting the horizontal position.

...

Further arguments to be passed to generic methods

Value

a plot of class ggplot


morseDR documentation built on June 8, 2025, 10:20 a.m.