PlotPPC: Plot the Posterior Predictive Chack on an object 'PPC'

PlotPPCR Documentation

Plot the Posterior Predictive Chack on an object PPC

Description

This is the generic plot S3 method for the PPC class. It plots the predicted values with 95 \ values for FitTT objects.

The coordinates of black points are the observed values of the number of survivors (pooled replicates) for a given concentration (X-axis) and the corresponding predicted values (Y-axis). 95\ value, colored in green if this interval contains the observed value and in red otherwise. The bisecting line (y = x) is added to the plot in order to see if each prediction interval contains each observed value. As replicates are shifted on the x-axis, this line is represented by steps.

Usage

## S3 method for class 'PPC'
plot(
  x,
  xlab = "Observation",
  ylab = "Prediction",
  main = NULL,
  dodge.width = 0,
  ...
)

Arguments

x

an object of class PPC

xlab

label of the x-axis

ylab

label of the y-axis

main

title of the graphic

dodge.width

dodging width. Dodging preserves the vertical position of an geom while adjusting the horizontal position. See position_dodge for further details.

...

Further arguments to be passed to generic methods

Value

a plot of class ggplot


morseDR documentation built on June 8, 2025, 10:20 a.m.