| Predict | R Documentation |
FitTTPrediction base on FitTT
predict(fit, ...)
## S3 method for class 'BinaryFitTT'
predict(fit, display.conc = NULL, ...)
## S3 method for class 'ContinuousFitTT'
predict(fit, display.conc = NULL, ...)
## S3 method for class 'CountFitTT'
predict(fit, display.conc = NULL, ...)
fit |
object of class |
... |
Further arguments to be passed to generic methods |
display.conc |
vector of concentrations values (x axis) |
A list of 3 elements: 'display.conc' a vector of the display concentration of exposure, 'mcmc': a data.frame of the mcmc and 'quantile' a data.frame of quantiles.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.