PriorPosterior: Return Prior and Posterior density of parameters of 'FitTT'...

PriorPosteriorR Documentation

Return Prior and Posterior density of parameters of FitTT object

Description

Return Prior and Posterior density of parameters of FitTT object

Extract posterior of parameters from a FitTT object#'

Usage

## S3 method for class 'PriorPosterior'
plot(x, xlab = "value", ylab = NULL, main = NULL, ...)

priorPosterior(fit, size_sample, ...)

## S3 method for class 'BinaryFitTT'
priorPosterior(fit, size_sample = 1000, ...)

## S3 method for class 'CountFitTT'
priorPosterior(fit, size_sample = 1000, ...)

## S3 method for class 'ContinuousFitTT'
priorPosterior(fit, size_sample = 1000, ...)

posterior(fit, ...)

## S3 method for class 'FitTT'
posterior(fit, ...)

Arguments

x

an object of class PriorPosterior

xlab

label of the x-axis

ylab

label of the y-axis

main

title of the graphic

...

Further arguments to be passed to generic methods

fit

An object of class FitTT

size_sample

graphical backend, can be 'generic' or 'ggplot'

Value

a data frame of class PriorPosterior

Return an object of class Posterior


morseDR documentation built on June 8, 2025, 10:20 a.m.