| Summary | R Documentation |
FitTT objectThis is the generic summary S3 method for the FitTT class.
It shows the quantiles of priors and posteriors on parameters and the quantiles
of the posteriors on the ECx and LCx estimates.
Summary function on PPC object
## S3 method for class 'BinaryFitTT'
summary(object, quiet = FALSE, ...)
## S3 method for class 'ContinuousFitTT'
summary(object, quiet = FALSE, ...)
## S3 method for class 'CountFitTT'
summary(object, quiet = FALSE, ...)
## S3 method for class 'PPC'
summary(object, quiet = FALSE, ...)
object |
an object of class |
quiet |
when |
... |
Further arguments to be passed to generic methods |
The function returns a list with the following information:
Qpriors |
quantiles of the model priors |
Qposteriors |
quantiles of the model posteriors |
QLCx |
quantiles of LCx estimates |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.