plant02: Continuous response of toxicity test on plants

plant02R Documentation

Continuous response of toxicity test on plants

Description

  • plant: Plant species exposed to a given product during 21 days for the vegetative vigour test. Shoot dry weight data is collected

Usage

data(plant02)

References

Charles, S., Wu, D., Ducrot, V. (2021). How to account for the uncertainty from standard toxicity tests in species sensitivity distributions: An example in non-target plants. PLOS ONE


morseDR documentation built on June 8, 2025, 10:20 a.m.