| plant07 | R Documentation |
plant: Plant species exposed to a given product during 21 days for the vegetative vigour test. Shoot dry weight data is collected
data(plant07)
Charles, S., Wu, D., Ducrot, V. (2021). How to account for the uncertainty from standard toxicity tests in species sensitivity distributions: An example in non-target plants. PLOS ONE
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.