| PlotData | R Documentation |
BinaryData, CountData or
ContinuousData.This is the generic plot S3 method for the BinaryData,
CountData and ContinuousData classes.
BinaryData: It plots the sum of non-failure (survivor, mobile)
individuals as a function of time.
CountData: It plots the cumulated number of offspring as a
function of time.
Continuous: It plots the continuous data as a
function of time by concentration panels.
## S3 method for class 'BinaryData'
plot(
x,
xlab = "Time",
ylab = "Sum of Non-Failure",
main = NULL,
concentration = NULL,
pool.replicate = FALSE,
addlegend = FALSE,
...
)
## S3 method for class 'ContinuousData'
plot(
x,
xlab = "Time",
ylab = "Measure",
main = NULL,
concentration = NULL,
addlegend = FALSE,
...
)
## S3 method for class 'CountData'
plot(
x,
xlab = "Time",
ylab = "Cumulated Response",
main = NULL,
concentration = NULL,
pool.replicate = FALSE,
addlegend = FALSE,
...
)
x |
an object of class |
xlab |
a label for the |
ylab |
a label for the |
main |
title for the plot |
concentration |
a numeric value corresponding to some concentration(s) in
|
pool.replicate |
if |
addlegend |
if |
... |
Further arguments to be passed to generic methods |
a plot of class ggplot
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.