| PlotDoseResponse | R Documentation |
DoseResponse objectsThis is the generic plot S3 method for the DoseResponse
class. It plots the survival probability as a function of concentration at a given
target time.
For BinaryData object: The function plots the observed values of
the survival probability at a given time point
as a function of concentration. The 95% binomial confidence interval is added
to each survival probability. It is calculated using function
binom.test from package stats.
Replicates are systematically pooled in this plot.
For CountData object: The function plots the observed values of
the Number of at a given time point
as a function of concentration. The 95% binomial confidence interval is added
to each survival probability. It is calculated using function
poisson.test.
Replicates are systematically pooled in this plot.
For ContinuousData object: the function plots observed values of the
response at a given time point as a function of concentration. The 95% binomial
confidence interval is added
to each set of data at each concentration. It is calculated using function
t.test from package stats.
## S3 method for class 'DoseResponse'
plot(
x,
xlab = "Dose",
ylab = NULL,
main = NULL,
log.scale = FALSE,
addlegend = TRUE,
dodge.width = 0,
...
)
## S3 method for class 'BinaryDoseResponse'
plot(
x,
xlab = "Concentration",
ylab = NULL,
main = NULL,
log.scale = FALSE,
addlegend = TRUE,
dodge.width = 0,
...
)
## S3 method for class 'CountDoseResponse'
plot(
x,
xlab = "Concentration",
ylab = NULL,
main = NULL,
log.scale = FALSE,
addlegend = TRUE,
dodge.width = 0,
...
)
## S3 method for class 'ContinuousDoseResponse'
plot(
x,
xlab = "Concentration",
ylab = NULL,
main = NULL,
log.scale = FALSE,
addlegend = TRUE,
dodge.width = 0,
...
)
x |
an object of class |
xlab |
a label for the |
ylab |
a label for the |
main |
main title for the plot |
log.scale |
if |
addlegend |
if |
dodge.width |
dodging width. Dodging preserves the vertical position of an geom while adjusting the horizontal position. |
... |
Further arguments to be passed to generic methods |
a plot of class ggplot
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.